 /********************************************************************/
 /*                                                                  */
 /*      Module:        PL/I I/O Request Block (IORB)                */
 /*      Version:       1.4                                          */
 /*      Date:          Sep, 2004                                    */
 /*      Author:        Peter Flass                                  */
 /*                                                                  */
 /*      Function:      Describes the request data passed to PL/I    */
 /*                     I/O routines.                                */
 /*                                                                  */
 /*      Length:        64 bytes ('40'x).                            */
 /*                                                                  */
 /*      Where held:    Temporary (stack) storage for the duration   */
 /*                     of an I/O operation.                         */
 /*                                                                  */
 /*      Created by:    I/O Statement                                */
 /*      Deleted by:    same                                         */
 /*                                                                  */
 /*      Dependencies:  Mapped in compiled code.                     */
 /*                     For version compatibility, add new data      */
 /*                     to end.                                      */
 /*                     'IOR_SRB' is the  same as the SRB            */
 /*                     structure and 'GPSB_SRB' in the GPSB.        */
 /*                                                                  */
 /*      Modifications:                                              */
 /*                     Version 1.4: Remap fields into IOR_SRB'.     */
 /*                     Version 1.3: Add 16 bytes.                   */
 /*                     Version 1.2a Add IOR_condmask.               */
 /*                     Version 1.2: Add 8 bytes.                    */
 /*                     Version 1.x: Move back to stack.             */
 /*                     Version 1.1: add pDSA pOpt, pDesc, pName.    */
 /*                                                                  */
 /*                                                                  */
 /********************************************************************/

 dcl   1 IORB                aligned based,
         5 IOR_Ver           fixed bin(15),      /* IORB version   00*/
         /*  Change version when the format of the IORB changes.     */
         /*  Current version is 1.                                   */
         5 IOR_Func          fixed bin(15),      /* I/O Function   02*/
         /*  1: Open         +--              ----                 --*/
         /*  2: Close        |  These are arbitrary codes,           */
         /* 10: Read         |  but the runtime library              */
         /* 11: Write        |  must agree with the code             */
         /* 12: Rewrite      |  generated by GIO.                    */
         /* 13: Locate       |                                       */
         /* 14: Delete       |                                       */
         /* 15: Unlock       |                                       */
         /* 20: Get          |                                       */
         /* 21: Put          |                                       */
         /* 30: Lineno BIF   |                                       */
         /* 31: Count BIF    |                                       */
         /* 35: Status       +--              ----                 --*/
         5 IOR_pFile         ptr,                /* -> FILE var    04*/
         5 IOR_pDCLCB        ptr,                /* -> Declared att08*/
         5 IOR_SRB,                              /* IORB Stream dat0C*/
           10 IOR_pDSA       ptr,                /* -> Curr DSA    0C*/
           10 IOR_pOPT       ptr,                /* -> Variable Opt10*/
           10 IOR_bOpt       bit(32),            /* Option bits    14*/
           10 IOR_pFmt       ptr,                /* -> Format item 18*/
           10 IOR_pData      ptr,                /* -> Data        1C*/
           10 IOR_pDesc      ptr,                /* -> Data Desc   20*/
           10 IOR_pName      ptr,                /* -> Data Name   24*/
           10 IOR_aFmt       ptr,                /* R format chain 28*/
           10 IOR_condmask   bit(16),            /* Enabled cond   2C*/
           10 fil1           char(2),            /* (alignment)    2E*/
         5 fil2              char(16),           /* unused         30*/
         5 IOR_end           char(0);            /* End of IORB    40*/

 /* Definitions of variable options.  Options are stored             */
 /* contiguously beginning at address IOR_pOpt.  Options are in      */
 /* order by sequence of IOR_bOpt.                                   */
 /* Each option is one of the following:                             */
 dcl     IOR_optF            fixed bin(31) based;/* FIXED_option     */
 dcl     IOR_optP            ptr           based;/* -> other_option  */

